@@ -21,7 +21,6 @@ from IPython.utils import py3compat
 # Code
 #-----------------------------------------------------------------------------
 
-@py3compat.doctest_refactor_print
 def extract_vars(*names,**kw):
     """Extract a set of variables by name from another frame.
 
@@ -50,7 +49,7 @@ def extract_vars(*names,**kw):
     """
 
     depth = kw.get('depth',0)
-    
+
     callerNS = sys._getframe(depth+1).f_locals
     return dict((k,callerNS[k]) for k in names)
 
@@ -59,7 +58,7 @@ def extract_vars_above(*names):
     """Extract a set of variables by name from another frame.
 
     Similar to extractVars(), but with a specified depth of 1, so that names
-    are exctracted exactly from above the caller.
+    are extracted exactly from above the caller.
 
     This is simply a convenience function so that the very common case (for us)
     of skipping exactly 1 frame doesn't have to construct a special dict for
@@ -94,4 +93,3 @@ def extract_module_locals(depth=0):
     global_ns = f.f_globals
     module = sys.modules[global_ns['__name__']]
     return (module, f.f_locals)
-
